import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Colors for the sections in Pie Chart
const sectionColors = [
  		'red', 'blue', 'yellow', 'lime', 'orange', 'skyblue', 'crimson', 'wheat', 'turquoise', 'aqua'
		  ];

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/AISWARYAMARAPATLA1999/7e5c82e944543c3183109f0ea742eadb/raw/c70ad0f91928eb131484f53f0c16bd11a156c14c/Ratings.csv';
// Function to fetch data from the URI
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};


// Select the SVG from the HTML body
const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// Format axes text
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Render Pie Chart on the canvas
const render = (data, total) => {
  const pieData = pie().value(d=>d.Rating)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // Object for generating Arcs of the sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  // Segments are the partition in the Pie Chart
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Rating));
  

  
  
  // Render legend for the data
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
   
  
  // Formats the legend for Deaths
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Rating));
  
  legend.append("text")
  	.attr("x", 300)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Rating)));
  
  // Formats the legend for Countries 
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Movies);
  
}

// Main function
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Rating = +d.Rating;
    total += d.Rating
  });
	render(data,total);
};
run();